==> alfred-ui-native-components-0.0.158.tgz: package/ui/widgets/details/switchAndDimmer/components/setSwitch/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText, LabelRegularText, SwitchLarge } from '../../../../../atoms';
import { BinarySubtitleModel, LoadingInfoTextModel } from '../../../widgetDetailModels';
import { styles } from './styles';

interface Props {
  title?: string;
  subtitle?: BinarySubtitleModel;
  loadingInfoTextOptions?: LoadingInfoTextModel;
  value?: boolean;
  onValueChange?: (response: boolean) => void;
  loading?: boolean;
  enabled?: boolean;
}

export const SetSwitch: FC<Props> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  value = false,
  onValueChange,
  loading = false,
  enabled = true,
}) => {
  const subtitleOn = subtitle?.on;
  const subtitleOff = subtitle?.off;
  const switchingOnInfoText = loadingInfoTextOptions?.option1;
  const switchingOffInfoText = loadingInfoTextOptions?.option2;
  const adjustingInfoText = loadingInfoTextOptions?.option3;
  
  return (
    <View style={styles.setSwitchWrapper}>
      <View>
        <LabelRegularText>{title}</LabelRegularText>
        {!loading &&
          <Body2RegularText color={styles.setSwitchContent.color}>
            {!value ? subtitleOff : subtitleOn}
          </Body2RegularText>
        }
        {loading && enabled &&
          <Body2RegularText color={styles.setSwitchContent.color}>
            {value ?
              adjustingInfoText :
              switchingOnInfoText
            }
          </Body2RegularText>
        }
        {loading && !enabled &&
          <Body2RegularText color={styles.setSwitchContent.color}>
            {switchingOffInfoText}
          </Body2RegularText>
        }
      </View>
      <SwitchLarge
        disabled={loading}
        loading={loading}
        onValueChange={() => onValueChange && onValueChange(!value)}
        value={enabled}
      />
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/widgets/details/switchAndDimmer/components/setSwitch/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { Body2RegularText, LabelRegularText, SwitchLarge } from '../../../../../atoms';
import { BinarySubtitleModel, LoadingInfoTextModel } from '../../../widgetDetailModels';
import { styles } from './styles';

interface Props {
  title?: string;
  subtitle?: BinarySubtitleModel;
  loadingInfoTextOptions?: LoadingInfoTextModel;
  value?: boolean;
  onValueChange?: (response: boolean) => void;
  loading?: boolean;
  enabled?: boolean;
}

export const SetSwitch: FC<Props> = ({
  title,
  subtitle,
  loadingInfoTextOptions,
  value = false,
  onValueChange,
  loading = false,
  enabled = true,
}) => {
  const subtitleOn = subtitle?.on;
  const subtitleOff = subtitle?.off;
  const switchingOnInfoText = loadingInfoTextOptions?.option1;
  const switchingOffInfoText = loadingInfoTextOptions?.option2;
  const adjustingInfoText = loadingInfoTextOptions?.option3;

  return (
    <View style={styles().setSwitchWrapper}>
      <View>
        <LabelRegularText>{title}</LabelRegularText>
        {!loading &&
          <Body2RegularText color={styles().setSwitchContent.color}>
            {!value ? subtitleOff : subtitleOn}
          </Body2RegularText>
        }
        {loading && enabled &&
          <Body2RegularText color={styles().setSwitchContent.color}>
            {value ?
              adjustingInfoText :
              switchingOnInfoText
            }
          </Body2RegularText>
        }
        {loading && !enabled &&
          <Body2RegularText color={styles().setSwitchContent.color}>
            {switchingOffInfoText}
          </Body2RegularText>
        }
      </View>
      <SwitchLarge
        disabled={loading}
        loading={loading}
        onValueChange={() => onValueChange && onValueChange(!value)}
        value={enabled}
      />
    </View>
  );
};
